<h1>Eureka Connection</h1>

<h3>Info Parameter on <i>DiscoveryClient</i> constructor:</h3>
<br>
INFO_DISCOVER = {<br>
    "PROTOCOL": ...<br>
    "HOSTDISCOVER": ...<br>
    "PORTDISCOVER": ...<br>
    "SERVICENAME": ...<br>
    "HOSTINSTANCE": ...<br>
    "PORTINSTANCE": ...<br>
    "HEARTBEATDISCOVER": ...<br>
}
